Firefly

Firefly has gone to sleep after spending too long between rendering frames, click to wake it back up!
Hint: if this is happening frequently it might be because Firefly is being overtaxed!
A WebGL tool to explore particle-based data
Aaron Geller / Alex Gurvich / Northwestern

Instructions:

- Right-click and drag with the mouse to rotate your view.
- Use the mouse wheel to zoom in and out.
- Click the Controls bar on the top left to show/hide a user interface.
- Detailed instructions can be found on the Firefly GitHub page.
- h: toggles this help screen on and off.

Loading...
▼